@@ -25,12 +25,12 @@
 #include <libebackend/e-extensible.h>
 
 #include <e-util/e-marshal.h>
-#include <e-util/e-alert-dialog.h>
+#include <libevolution-utils/e-alert-dialog.h>
 
 #include <libemail-utils/e-account-utils.h>
 #include <libemail-engine/mail-ops.h>
 
-#include <mail/mail-vfolder.h>
+#include <mail/mail-vfolder-ui.h>
 
 #define E_MAIL_ACCOUNT_STORE_GET_PRIVATE(obj) \
 	(G_TYPE_INSTANCE_GET_PRIVATE \
