@@ -32,7 +32,7 @@
 #include <gtkhtml/gtkhtml.h>
 #include <camel/camel.h>
 
-#include "e-util/e-alert-dialog.h"
+#include "libevolution-utils/e-alert-dialog.h"
 #include "filter/e-filter-rule.h"
 #include "misc/e-web-view.h"
 #include "shell/e-shell-utils.h"
@@ -48,7 +48,7 @@
 #include "mail/em-format-html-print.h"
 #include "mail/em-utils.h"
 #include "mail/mail-autofilter.h"
-#include "mail/mail-vfolder.h"
+#include "mail/mail-vfolder-ui.h"
 #include "mail/message-list.h"
 
 typedef struct _AsyncContext AsyncContext;
@@ -855,7 +855,9 @@ e_mail_reader_reply_to_message (EMailReader *reader,
 
 			if (curl && curl->path && *curl->path) {
 				address = camel_internet_address_new ();
-				if (camel_address_decode (CAMEL_ADDRESS (address), curl->path) < 0) {
+				if (camel_address_decode (
+						CAMEL_ADDRESS (address),
+						curl->path) < 0) {
 					g_object_unref (address);
 					address = NULL;
 				}
