@@ -41,10 +41,10 @@
 
 #include "e-util/e-mktemp.h"
 
-#include "e-util/e-alert-dialog.h"
+#include "libevolution-utils/e-alert-dialog.h"
 #include "e-util/e-dialog-utils.h"
 
-#include "em-vfolder-rule.h"
+#include "em-vfolder-editor-rule.h"
 
 #include "libemail-utils/mail-mt.h"
 #include "libemail-engine/e-mail-folder-utils.h"
@@ -62,7 +62,7 @@
 #include "em-folder-utils.h"
 #include "em-folder-selector.h"
 #include "em-folder-properties.h"
-#include "mail-vfolder.h"
+#include "mail-vfolder-ui.h"
 
 #define d(x)
 
@@ -655,7 +655,7 @@ em_folder_utils_create_folder (GtkWindow *parent,
 		else
 			skip_slash = folder_name;
 
-		rule = em_vfolder_rule_new (session);
+		rule = em_vfolder_editor_rule_new (session);
 		e_filter_rule_set_name (rule, skip_slash);
 		vfolder_gui_add_rule (EM_VFOLDER_RULE (rule));
 	} else {
