@@ -25,7 +25,7 @@
 
 #include <shell/e-shell.h>
 
-#include <e-util/e-alert-dialog.h>
+#include <libevolution-utils/e-alert-dialog.h>
 #include <e-util/e-import.h>
 
 #include <libemail-utils/e-account-utils.h>
@@ -565,7 +565,7 @@ startup_wizard_run (EStartupWizard *extension)
 	gtk_main ();
 
 	if (e_list_length (E_LIST (account_list)) <= 0)
-		exit(0);
+		exit (0);
 
 }
 
