@@ -33,7 +33,7 @@
 #include <glib/gstdio.h>
 #include "mail/em-config.h"
 #include "mail/em-account-editor.h"
-#include "e-util/e-alert-dialog.h"
+#include "libevolution-utils/e-alert-dialog.h"
 #include "e-util/e-util.h"
 #include "e-util/e-dialog-utils.h"
 #include "shell/e-shell-utils.h"
@@ -44,7 +44,9 @@
 #undef localtime_r
 #endif
 /* The localtime() in Microsoft's C library *is* thread-safe */
-#define localtime_r(timep, result)  (localtime (timep) ? memcpy ((result), localtime (timep), sizeof (*(result))) : 0)
+#define localtime_r(timep, result) \
+	(localtime (timep) ? memcpy ( \
+	(result), localtime (timep), sizeof (*(result))) : 0)
 #endif
 
 gboolean	e_plugin_ui_init	(GtkUIManager *ui_manager,
