@@ -35,8 +35,8 @@
 #include <libebackend/e-extensible.h>
 
 #include "e-util/e-util.h"
-#include "e-util/e-alert-dialog.h"
-#include "e-util/e-alert-sink.h"
+#include "libevolution-utils/e-alert-dialog.h"
+#include "libevolution-utils/e-alert-sink.h"
 #include "filter/e-rule-editor.h"
 #include "widgets/misc/e-action-combo-box.h"
 #include "widgets/misc/e-alert-bar.h"
