@@ -31,6 +31,10 @@
 #include "e-signature-tree-view.h"
 #include "e-signature-script-dialog.h"
 
+#define E_SIGNATURE_MANAGER_GET_PRIVATE(obj) \
+	(G_TYPE_INSTANCE_GET_PRIVATE \
+	((obj), E_TYPE_SIGNATURE_MANAGER, ESignatureManagerPrivate))
+
 struct _ESignatureManagerPrivate {
 	ESignatureList *signature_list;
 
@@ -234,7 +238,7 @@ signature_manager_dispose (GObject *object)
 {
 	ESignatureManagerPrivate *priv;
 
-	priv = E_SIGNATURE_MANAGER (object)->priv;
+	priv = E_SIGNATURE_MANAGER_GET_PRIVATE (object);
 
 	if (priv->signature_list != NULL) {
 		g_object_unref (priv->signature_list);
@@ -526,8 +530,7 @@ e_signature_manager_init (ESignatureManager *manager)
 	GtkWidget *container;
 	GtkWidget *widget;
 
-	manager->priv = G_TYPE_INSTANCE_GET_PRIVATE (
-		manager, E_TYPE_SIGNATURE_MANAGER, ESignatureManagerPrivate);
+	manager->priv = E_SIGNATURE_MANAGER_GET_PRIVATE (manager);
 
 	gtk_table_resize (GTK_TABLE (manager), 1, 2);
 	gtk_table_set_col_spacings (GTK_TABLE (manager), 6);
